Index: tools/gpu/gl/angle/GLTestContext_angle.h |
diff --git a/tools/gpu/gl/angle/GLContext_angle.h b/tools/gpu/gl/angle/GLTestContext_angle.h |
similarity index 54% |
rename from tools/gpu/gl/angle/GLContext_angle.h |
rename to tools/gpu/gl/angle/GLTestContext_angle.h |
index 519ea6b5a3969eab32067eb726e04365da1d19bb..0140477a54db55742d459d3714ab76557c16d4b8 100644 |
--- a/tools/gpu/gl/angle/GLContext_angle.h |
+++ b/tools/gpu/gl/angle/GLTestContext_angle.h |
@@ -5,10 +5,10 @@ |
* Use of this source code is governed by a BSD-style license that can be |
* found in the LICENSE file. |
*/ |
-#ifndef GLContext_angle_DEFINED |
-#define GLContext_angle_DEFINED |
+#ifndef GLTestContext_angle_DEFINED |
+#define GLTestContext_angle_DEFINED |
-#include "gl/GLContext.h" |
+#include "gl/GLTestContext.h" |
namespace sk_gpu_test { |
@@ -19,12 +19,12 @@ namespace sk_gpu_test { |
const GrGLInterface* CreateANGLEGLInterface(); |
#ifdef SK_BUILD_FOR_WIN |
-/** Creates a GLContext backed by ANGLE's Direct3D backend. */ |
-GLContext* CreateANGLEDirect3DGLContext(); |
+/** Creates a GLTestContext backed by ANGLE's Direct3D backend. */ |
+GLTestContext* CreateANGLEDirect3DGLTestContext(); |
#endif |
-/** Creates a GLContext backed by ANGLE's OpenGL backend. */ |
-GLContext* CreateANGLEOpenGLGLContext(); |
+/** Creates a GLTestContext backed by ANGLE's OpenGL backend. */ |
+GLTestContext* CreateANGLEOpenGLGLTestContext(); |
} // namespace sk_gpu_test |
#endif |